package com.example.service;

import com.azure.data.appconfiguration.ConfigurationClient;
import com.azure.data.appconfiguration.ConfigurationClientBuilder;
import com.azure.data.appconfiguration.models.SettingSelector;
import org.junit.Before;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class AzureAppConfigServiceTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(AzureAppConfigServiceTest.class);
    private static final String APP_CONFIGURATION_CONNECTION_STRING = "APP_CONFIGURATION_CONNECTION_STRING";
    private static final String EXISTING_KEY = "config.message";
    private static final String EXISTING_VALUE = "This is Azure App Config";
    private static final String NEW_KEY = "config.dataSource";
    private static final String NEW_VALUE = "Data Source URL";
    private AzureAppConfigService azureAppConfigService;

    @Before
    public void setUp() {
        String app_configuration_connection_string = System.getenv(APP_CONFIGURATION_CONNECTION_STRING);
        ConfigurationClient configurationClient = new ConfigurationClientBuilder().connectionString(app_configuration_connection_string).buildClient();
        azureAppConfigService = new AzureAppConfigService(configurationClient, new SettingSelector());
    }

    @Test
    public void getValueByKey() {
        String valueByKey = azureAppConfigService.getValueByKey(EXISTING_KEY);
        LOGGER.info(valueByKey);
        assertNotNull(valueByKey);
        assertEquals(EXISTING_VALUE, valueByKey);
    }

    @Test
    public void writeValueByKey() {
        String writeValueByKey = azureAppConfigService.writeValueByKey(NEW_KEY, NEW_VALUE);
        LOGGER.info(writeValueByKey);
        assertNotNull(writeValueByKey);
        assertEquals(NEW_VALUE, writeValueByKey);
    }

    @Test
    public void readAllKeyValue() {
        long count = azureAppConfigService.readAllKeyValue().stream().count();
        assertEquals(3, count);
    }

    @Test
    public void deleteValueByKey() {
        String valueByKey = azureAppConfigService.deleteValueByKey(NEW_KEY);
        LOGGER.info(valueByKey);
        assertNotNull(valueByKey);
        assertEquals(NEW_VALUE, valueByKey);
    }
}